@@ -28,21 +28,13 @@
 #ifndef GEANY_TEMPLATES_H
 #define GEANY_TEMPLATES_H 1
 
+#include "document.h"
+#include "filetypes.h"
+
+#include <glib.h>
+
 G_BEGIN_DECLS
 
-#define GEANY_TEMPLATES_INDENT 3
-
-enum
-{
-	GEANY_TEMPLATE_GPL = 0,
-	GEANY_TEMPLATE_BSD,
-	GEANY_TEMPLATE_FILEHEADER,
-	GEANY_TEMPLATE_CHANGELOG,
-	GEANY_TEMPLATE_FUNCTION,
-	GEANY_MAX_TEMPLATES
-};
-
-
 /** Template preferences. */
 typedef struct GeanyTemplatePrefs
 {
@@ -57,14 +49,34 @@ typedef struct GeanyTemplatePrefs
 }
 GeanyTemplatePrefs;
 
-extern GeanyTemplatePrefs template_prefs;
 
+gchar *templates_get_template_fileheader(gint filetype_idx, const gchar *fname);
+
+
+#ifdef GEANY_PRIVATE
 
 struct filetype;
 
-void templates_init(void);
+#define GEANY_TEMPLATES_INDENT 3
+#define GEANY_TEMPLATES_FORMAT_YEAR              C_("DefaultYear", "%Y")
+#define GEANY_TEMPLATES_FORMAT_DATE              C_("DefaultDate", "%Y-%m-%d")
+#define GEANY_TEMPLATES_FORMAT_DATETIME          C_("DefaultDateTime", "%d.%m.%Y %H:%M:%S %Z")
 
-gchar *templates_get_template_fileheader(gint filetype_idx, const gchar *fname);
+enum
+{
+	GEANY_TEMPLATE_GPL = 0,
+	GEANY_TEMPLATE_BSD,
+	GEANY_TEMPLATE_FILEHEADER,
+	GEANY_TEMPLATE_CHANGELOG,
+	GEANY_TEMPLATE_FUNCTION,
+	GEANY_MAX_TEMPLATES
+};
+
+
+extern GeanyTemplatePrefs template_prefs;
+
+
+void templates_init(void);
 
 gchar *templates_get_template_changelog(GeanyDocument *doc);
 
@@ -80,6 +92,8 @@ void templates_replace_valist(GString *text,
 
 void templates_free_templates(void);
 
+#endif /* GEANY_PRIVATE */
+
 G_END_DECLS
 
-#endif
+#endif /* GEANY_TEMPLATES_H */
